==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property fileSystemId The ID of the file system, assigned by Amazon EFS.
 * @property path The pathname for the folder being used by a workflow.
 */
public data class WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs(
    public val fileSystemId: Output<String>? = null,
    public val path: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.transfer.inputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs> {
    override fun toJava():
        com.pulumi.aws.transfer.inputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs =
        com.pulumi.aws.transfer.inputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.builder()
            .fileSystemId(fileSystemId?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs].
 */
@PulumiTagMarker
public class WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgsBuilder
internal constructor() {
    private var fileSystemId: Output<String>? = null

    private var path: Output<String>? = null

    /**
     * @param value The ID of the file system, assigned by Amazon EFS.
     */
    @JvmName("xitpoxlinbsfpnwo")
    public suspend fun fileSystemId(`value`: Output<String>) {
        this.fileSystemId = value
    }

    /**
     * @param value The pathname for the folder being used by a workflow.
     */
    @JvmName("qtrbwwviqtdwfhbi")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The ID of the file system, assigned by Amazon EFS.
     */
    @JvmName("nsftcvjabivjjajb")
    public suspend fun fileSystemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystemId = mapped
    }

    /**
     * @param value The pathname for the folder being used by a workflow.
     */
    @JvmName("goqdvuxlgbkgnhsr")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    internal fun build(): WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs =
        WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs(
            fileSystemId = fileSystemId,
            path = path,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property fileSystemId The ID of the file system, assigned by Amazon EFS.
 * @property path The pathname for the folder being used by a workflow.
 */
public data class WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs(
    public val fileSystemId: Output<String>? = null,
    public val path: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.transfer.inputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs> {
    override fun toJava(): com.pulumi.aws.transfer.inputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs =
        com.pulumi.aws.transfer.inputs.WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.builder()
            .fileSystemId(fileSystemId?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs].
 */
@PulumiTagMarker
public class WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgsBuilder
internal constructor() {
    private var fileSystemId: Output<String>? = null

    private var path: Output<String>? = null

    /**
     * @param value The ID of the file system, assigned by Amazon EFS.
     */
    @JvmName("usryuouecrmogvlb")
    public suspend fun fileSystemId(`value`: Output<String>) {
        this.fileSystemId = value
    }

    /**
     * @param value The pathname for the folder being used by a workflow.
     */
    @JvmName("ayxyqifgvfrbnjba")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The ID of the file system, assigned by Amazon EFS.
     */
    @JvmName("kqxsxwpmyqevbllx")
    public suspend fun fileSystemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystemId = mapped
    }

    /**
     * @param value The pathname for the folder being used by a workflow.
     */
    @JvmName("vgpvqghqmfpkvvkp")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    internal fun build(): WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs =
        WorkflowStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs(
            fileSystemId = fileSystemId,
            path = path,
        )
}
